summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2005-03-04 01:02:24 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2005-03-04 01:02:24 +0000
commit867d89a08d8b81f3148b6f3c0c8fca610e3d670a (patch)
treef3c17e9a794c129037a762b914c74449914444b7
parentfb49993c106fe9d222c7217af6f01d1297367c5d (diff)
downloadATCD-867d89a08d8b81f3148b6f3c0c8fca610e3d670a.tar.gz
ChangeLogTag:Thu Mar 3 12:17:12 UTC 2005 Johnny Willemsen <jwillemsen@remedy.nl>
-rw-r--r--ace/Thread_Manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/ace/Thread_Manager.h b/ace/Thread_Manager.h
index 51d09cdadca..c1643367768 100644
--- a/ace/Thread_Manager.h
+++ b/ace/Thread_Manager.h
@@ -487,12 +487,12 @@ public:
// argument is not modified.
/**
* Create a new thread, which executes <func>.
* Returns: on success a unique group id that can be used to control
* other threads added to the same group. On failure, returns -1.
*/
int spawn (ACE_THR_FUNC func,
- void *args = 0,
+ void *arg = 0,
long flags = THR_NEW_LWP | THR_JOINABLE | THR_INHERIT_SCHED,
ACE_thread_t * = 0,
ACE_hthread_t *t_handle = 0,
@@ -532,7 +532,7 @@ public:
*/
int spawn_n (size_t n,
ACE_THR_FUNC func,
- void *args = 0,
+ void *arg = 0,
long flags = THR_NEW_LWP | THR_JOINABLE | THR_INHERIT_SCHED,
long priority = ACE_DEFAULT_THREAD_PRIORITY,
int grp_id = -1,
@@ -573,7 +573,7 @@ public:
int spawn_n (ACE_thread_t thread_ids[],
size_t n,
ACE_THR_FUNC func,
- void *args,
+ void *arg,
long flags,
long priority = ACE_DEFAULT_THREAD_PRIORITY,
int grp_id = -1,
@@ -944,7 +944,7 @@ protected:
/// Create a new thread (must be called with locks held).
virtual int spawn_i (ACE_THR_FUNC func,
- void *args,
+ void *arg,
long flags,
ACE_thread_t * = 0,
ACE_hthread_t *t_handle = 0,
@@ -487,12 +487,12 @@ public:
// argument is not modified.
/**
- * Create a new thread, which executes <func>.
+ * Create a new thread, which executes <func> with argument <arg>.
* Returns: on success a unique group id that can be used to control
* other threads added to the same group. On failure, returns -1.